@@ -12,7 +12,7 @@
 
 
 # Define a common label for all the tmp files
-label="bufr_read_scatterometer_c"
+label="examples_c_bufr_read_scatterometer"
 
 # Define tmp file
 fTmp=${label}.tmp.txt
