@@ -399,7 +399,7 @@ void BufrDecodeC::dump_string_array(grib_accessor* a, const char* comment)
     empty_ = 0;
     values = (char**)grib_context_malloc_clear(c, size * sizeof(char*));
     if (!values) {
-        grib_context_log(c, GRIB_LOG_ERROR, "unable to allocate %zu bytes", size);
+        grib_context_log(c, GRIB_LOG_ERROR, "Unable to allocate %zu bytes", size);
         return;
     }
 
