@@ -447,12 +447,9 @@ struct grib_string_list
     grib_string_list* next;
 };
 
+/* The 'what' argument can be a bitwise OR of GRIB_SECTION_GRID, GRIB_SECTION_PRODUCT... etc */
 grib_handle* grib_util_sections_copy(grib_handle* hfrom, grib_handle* hto, int what, int* err);
 
-/* These 2 functions are deprecated and will later be removed */
-grib_string_list* grib_util_get_param_id(const char* mars_param);
-grib_string_list* grib_util_get_mars_param(const char* param_id);
-
 /**
  *  Create a handle from a user message in memory. The message will not be freed at the end.
  *  The message will be copied as soon as a modification is needed.
@@ -1175,6 +1172,7 @@ void grib_context_set_samples_path(grib_context* c, const char* path);
 
 void grib_context_set_debug(grib_context* c, int mode);
 void grib_context_set_data_quality_checks(grib_context* c, int val);
+char* grib_context_full_defs_path(grib_context* c, const char* basename);
 
 /**
  *  Sets the context printing procedure used for user interaction
@@ -1191,6 +1189,7 @@ void grib_context_set_print_proc(grib_context* c, grib_print_proc printp);
  * @param logp         : the logging procedure to be set @see grib_log_proc
  */
 void grib_context_set_logging_proc(grib_context* c, grib_log_proc logp);
+void grib_context_set_logging_file(grib_context* c, FILE*);
 
 /**
  *  Turn on support for multi-fields in single GRIB messages
@@ -1351,6 +1350,9 @@ int wmo_read_any_from_file(FILE* f, void* buffer, size_t* len);
 int wmo_read_grib_from_file(FILE* f, void* buffer, size_t* len);
 int wmo_read_bufr_from_file(FILE* f, void* buffer, size_t* len);
 int wmo_read_gts_from_file(FILE* f, void* buffer, size_t* len);
+/* if f support ftell, offset is updated with the absolute position within the file, */
+/* otherwise, it accumulates the position across a series of calls */
+int wmo_read_any_from_file_with_offset(FILE* f, void* buffer, size_t* len, off_t* offset);
 int wmo_read_any_from_stream(void* stream_data, long (*stream_proc)(void*, void* buffer, long len), void* buffer, size_t* len);
 
 /* These functions allocate memory for the result so the user is responsible for freeing it */
@@ -1740,5 +1742,7 @@ Error codes returned by the grib_api functions.
 #define GRIB_UNABLE_TO_COMPARE_ACCESSORS		-78
 /** Assertion failure */
 #define GRIB_ASSERTION_FAILURE		-79
+/** Runtime error */
+#define GRIB_RUNTIME_ERROR		-80
 /*! @}*/
 #endif
