@@ -16,17 +16,20 @@ tempOut=temp.$label.txt
 
 [ -z "$ECCODES_DEFINITION_PATH" ] || ECCODES_DEFINITION_PATH=`${tools_dir}/codes_info -d`
 
-for file in `find ${ECCODES_DEFINITION_PATH}/ -name '*.def' -print | grep -v grib3/`
+# Ignore symbolic links
+# Ignore unsupported formats e.g., TAF, METAR
+for file in `find ${ECCODES_DEFINITION_PATH}/ -name '*.def' -type f -print | grep -v grib3/ | grep -v metar/ | grep -v taf/`
 do
-  ${tools_dir}/codes_parser $file > $REDIRECT
+  ${bin_dir}/codes_parser $file > $REDIRECT
 done
 
 # Try an invalid input
 set +e
-echo 'transient xx=1' | ${tools_dir}/codes_parser - 2>$tempOut
+echo 'transient xx=1' | ${bin_dir}/codes_parser - 2>$tempOut
 status=$?
 set -e
 [ $status -ne 0 ]
 grep -q "Parser: syntax error" $tempOut
 
+# Clean up
 rm -f $tempOut
