@@ -8,11 +8,11 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
 REDIRECT=/dev/null
 
-label="grib1to3"
+label="grib1to3_test"
 temp=temp.$label.grib3
 sample_g1=$ECCODES_SAMPLES_PATH/GRIB1.tmpl
 ${tools_dir}/grib_set -s editionNumber=3 $sample_g1 $temp
