@@ -55,8 +55,8 @@ grib_check_key_equals $temp constituentType,numberOfModeOfDistribution,modeNumbe
 
 # Plain aerosols
 ${tools_dir}/grib_set -s tablesVersion=$latest,is_aerosol=1 $sample2 $temp
-grib_check_key_equals $temp productDefinitionTemplateNumber '48'
-grib_check_key_equals $temp aerosolType,typeOfSizeInterval,typeOfWavelengthInterval '0 0 0'
+grib_check_key_equals $temp productDefinitionTemplateNumber '50'
+grib_check_key_equals $temp aerosolType,typeOfSizeInterval '0 0'
 
 # Aerosol optical
 ${tools_dir}/grib_set -s tablesVersion=$latest,is_aerosol_optical=1 $sample2 $temp
@@ -119,13 +119,32 @@ grib_check_key_equals $temp aerosolType,typeOfSizeInterval '0 0'
 ${tools_dir}/grib_set -s paramId=210072 $tempSample $temp
 ${tools_dir}/grib_ls -p firstSize,secondSize $temp
 
+
+# =============================
+# Ensemble interval-based
+# =============================
+tempSample=temp.sample.$label
+${tools_dir}/grib_set -s tablesVersion=$latest,productDefinitionTemplateNumber=11,typeOfStatisticalProcessing=1 $sample2 $tempSample
+grib_check_key_equals $tempSample stepType,perturbationNumber 'accum 0'
+
+${tools_dir}/grib_set -s is_chemical=1 $tempSample $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '43'
+grib_check_key_equals $temp constituentType,perturbationNumber,stepType '0 0 accum'
+
+${tools_dir}/grib_set -s is_chemical_srcsink=1 $tempSample $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '79'
+
+${tools_dir}/grib_set -s is_chemical_distfn=1 $tempSample $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber '68'
+
+
 # ECC-1303: Setting localDefinitionNumber=1 on chemical source/sink
 # ------------------------------------------------------------------
 ${tools_dir}/grib_set -s paramId=228104,setLocalDefinition=1,localDefinitionNumber=1 $sample2 $temp
 grib_check_key_equals $temp paramId,productDefinitionTemplateNumber,is_chemical_srcsink,localUsePresent '228104 76 1 1'
 
-${tools_dir}/grib_set -s stepType=accum,paramId=228104 $sample2 $temp
-grib_check_key_equals $temp shortName,productDefinitionTemplateNumber,is_chemical_srcsink 'e_WLCH4 78 1'
+${tools_dir}/grib_set -s paramId=228104 $sample2 $temp
+grib_check_key_equals $temp shortName,productDefinitionTemplateNumber,is_chemical_srcsink 'e_WLCH4 76 1'
 ${tools_dir}/grib_set -s setLocalDefinition=1,localDefinitionNumber=1 $temp $temp1
 ${tools_dir}/grib_compare -b totalLength,numberOfSection $temp $temp1
 grib_check_key_equals $temp1 localUsePresent 1
@@ -149,5 +168,10 @@ ${tools_dir}/grib_dump -O -p aerosolType $temp > $temp1
 grep -q "Nitrate Fine Mode .*grib2/tables/local/ecmf/1/4.233.table" $temp1
 grib_check_key_equals $temp aerosolTypeName "Nitrate Fine Mode"
 
+# Automatic PDT selection
+${tools_dir}/grib_set -s setLocalDefinition=1,class=a5,tablesVersion=34,paramId=403000 $sample2 $temp
+grib_check_key_equals $temp productDefinitionTemplateNumber,sourceSinkChemicalPhysicalProcess '76 255'
+
+
 # Clean up
 rm -f $tempSample $temp $temp1
