@@ -8,9 +8,9 @@
 # virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
 #
 
-. ./include.sh
+. ./include.ctest.sh
 
-label="grib_efas"
+label="grib_efas_test"
 sample=temp.sample.$label.grib
 temp1=temp1.$label.grib
 temp2=temp2.$label.grib
